Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(591)

Unified Diff: Source/core/rendering/svg/SVGRenderSupport.h

Issue 721073003: Pass PaintBehaviorRenderingClipPathAsMask in PaintInfo (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Constify; Add ASSERT. Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/rendering/svg/SVGRenderSupport.h
diff --git a/Source/core/rendering/svg/SVGRenderSupport.h b/Source/core/rendering/svg/SVGRenderSupport.h
index 6a3e878e29520561fb9a7ec079a13da681e3aa6c..60fd7ea2fe432d604dbaa5d32320e61d82652007 100644
--- a/Source/core/rendering/svg/SVGRenderSupport.h
+++ b/Source/core/rendering/svg/SVGRenderSupport.h
@@ -55,9 +55,6 @@ public:
// Helper function determining whether overflow is hidden.
static bool isOverflowHidden(const RenderObject*);
- // Returns true if we're currently within the rendering of a clip-path as a mask.
- static bool isRenderingClipPathAsMaskImage(const RenderObject&);
-
// Calculates the paintInvalidationRect in combination with filter, clipper and masker in local coordinates.
static void intersectPaintInvalidationRectWithResources(const RenderObject*, FloatRect&);
@@ -86,10 +83,10 @@ public:
static void applyStrokeStyleToContext(GraphicsContext*, const RenderStyle*, const RenderObject*);
static void applyStrokeStyleToStrokeData(StrokeData*, const RenderStyle*, const RenderObject*);
// Update the GC state (on |stateSaver.context()|) for painting |renderer|
// using |style|. |resourceMode| is used to decide between fill/stroke.
// Previous state will be saved (if needed) using |stateSaver|.
- static bool updateGraphicsContext(GraphicsContextStateSaver&, RenderStyle*, RenderObject&, RenderSVGResourceMode, const AffineTransform* additionalPaintServerTransform = 0);
+ static bool updateGraphicsContext(const PaintInfo&, GraphicsContextStateSaver&, RenderStyle*, RenderObject&, RenderSVGResourceMode, const AffineTransform* additionalPaintServerTransform = 0);
// Determines if any ancestor's transform has changed.
static bool transformToRootChanged(RenderObject*);
« no previous file with comments | « Source/core/rendering/svg/RenderSVGResourceClipper.cpp ('k') | Source/core/rendering/svg/SVGRenderSupport.cpp » ('j') | no next file with comments »
@@ -86,10 +83,10 @@ public:
static void applyStrokeStyleToContext(GraphicsContext*, const RenderStyle*, const RenderObject*);
static void applyStrokeStyleToStrokeData(StrokeData*, const RenderStyle*, const RenderObject*);
- // Update the GC state (on |stateSaver.context()|) for painting |renderer|
+ // Update the GC state (on |paintInfo.context|) for painting |renderer|
// using |style|. |resourceMode| is used to decide between fill/stroke.
// Previous state will be saved (if needed) using |stateSaver|.

Powered by Google App Engine
This is Rietveld 408576698